store

package
v1.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2025 License: MIT Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Contains added in v1.4.1

func Contains[T interface{ ~[]E }, E comparable](left, right T) bool

func Download

func Download(id string, version *ms.Version, locale *ms.Locale, destinationPath string) (*ms.BundleFileInfo, error)

Download backage and its dependencies from MS Store by id, version and locale to destination directory and returns array of backage and its dependencies paths.

func Equal

func Equal[T any](left, right []T, f func(l, r T) bool) bool

func PrettyString

func PrettyString(slice any) string

func ToSlice

func ToSlice[T any](iter iter.Seq[T]) []T

ToSlice converts iterator over sequence to slice.

Types

This section is empty.

Jump to