Documentation
¶
Index ¶
- func Contains[T interface{ ... }, E comparable](left, right T) bool
- func Download(id string, version *ms.Version, locale *ms.Locale, destinationPath string) (*ms.BundleFileInfo, error)
- func Equal[T any](left, right []T, f func(l, r T) bool) bool
- func PrettyString(slice any) string
- func ToSlice[T any](iter iter.Seq[T]) []T
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Contains ¶ added in v1.4.1
func Contains[T interface{ ~[]E }, E comparable](left, right T) bool
func Download ¶
func Download(id string, version *ms.Version, locale *ms.Locale, destinationPath string) (*ms.BundleFileInfo, error)
Download backage and its dependencies from MS Store by id, version and locale to destination directory and returns array of backage and its dependencies paths.
func PrettyString ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.